package edu.northwestern.dasu.drools;

import edu.northwestern.dasu.stats.RSTSystemStats;

/* 
 * For an member to be visible to Jess (as part of the fact)  
 *  it must have it's own public setter and getter functions
 */
public class FactMeasurementSystem extends FactMeasurement<RSTSystemStats> {

		public long timeRecorded = -1;
		private int rst = -1;
		private int numConnections=-1;
		private int passiveOpens=-1;
		private int activeOpens=-1;
		private int failedConns=-1;
		
		private Float averageRst=0f;
        private Float averageNumConnections=0f;
        private Float averagePassiveOpen=0f;
        private Float averageActiveOpen=0f;
        private Float averageFailedCons=0f;
		private Float stdevRst=0f;
        private Float stdevNumConnections=0f;
        private Float stdevPassiveOpen=0f;
        private Float stdevActiveOpen=0f;
        private Float stdevFailedCons=0f;

        private RSTSystemStats lastMeasurement = new RSTSystemStats();
		
		public FactMeasurementSystem(RSTSystemStats rststat) {

			this.timeRecorded = rststat.timeRecorded;
			this.rst = rststat.rst;
			this.numConnections = rststat.numConnections;
			this.passiveOpens = rststat.passiveOpens;
			this.activeOpens = rststat.activeOpens;
			this.failedConns = rststat.failedConns;
			
			if (DEBUG)
				System.out.println( rststat.timeRecorded + " " + rststat.numConnections + " " +
					rststat.passiveOpens + " "  + rststat.activeOpens + " " +
					rststat.failedConns);
			
			addEntry(rststat);
			
		}
		
		@Override
		public void addEntry(RSTSystemStats rststat) {

			RSTSystemStats tmp = (RSTSystemStats) rststat.clone();

			int size = entryList.size();
			if (size == 0) 
				lastMeasurement = tmp;
			
			if (size == maxNumEntries) {
				entryList.removeFirst();
				windowFull = true;
//				setWindowFull(true);
			}
			
			rststat.rst -= lastMeasurement.rst;
			rststat.numConnections -= lastMeasurement.numConnections;
			rststat.passiveOpens -= lastMeasurement.passiveOpens;
			rststat.activeOpens -= lastMeasurement.activeOpens;
			rststat.failedConns -= lastMeasurement.failedConns;				
			
			entryList.add(rststat);
			updateAll(rststat);
			lastMeasurement = tmp;
			
			updateTimeStamp();
			
		}

				
		@Override
		public void updateAll(RSTSystemStats rststat) {
						
			/* Holds the 3 times the number of entries in a movingWindow */
			if (entryList.size() == maxNumEntries * 3)
				entryList.removeFirst();

			entryList.add(rststat);
			
//			setTimeRecorded(rststat.timeRecorded);
//			setRst(rststat.rst);
//			setNumConnections(rststat.numConnections);
//			setPassiveOpens(rststat.passiveOpens);
//			setActiveOpens(rststat.activeOpens);
//			setFailedConns(rststat.failedConns);
			
			timeRecorded = (rststat.timeRecorded);
			rst = (rststat.rst);
			numConnections = (rststat.numConnections);
			passiveOpens = (rststat.passiveOpens);
			activeOpens = (rststat.activeOpens);
			failedConns = (rststat.failedConns);


			updateDynamic();
			
			
			if (DEBUG) {
				
				System.out.println("\nFactMeasurementSystem");			
				for (int i = 0; i < entryList.size(); i++ ) {
					System.out.println(entryList.get(i).timeRecorded + " RST " +
							entryList.get(i).rst + " numConnections: " + 
							entryList.get(i).numConnections + " passiveOpens: " +
							entryList.get(i).passiveOpens + " activeOpens: " + 
							entryList.get(i).activeOpens);
				}
			
				System.out.println("avgRST: " + averageRst + 
					" avgNunConn: " + averageNumConnections + 
					" avgPassiveOpens: " + averagePassiveOpen +
					" avgActiveOpens: " + averageActiveOpen);
				
				System.out.println();
			}

		}
		
				
		public long getTimeRecorded() {
			return timeRecorded;
		}

		public int getRst() {
			return rst;
		}
		
		public int getNumConnections() {
			return numConnections;
		}
		
		public int getPassiveOpens() {
			return passiveOpens;
		}
		
		public int getActiveOpens() {
			return activeOpens;
		}
		
		public int getFailedConns() {
			return failedConns;
		}

		public Float getAverageRst() {
			return averageRst;
		}

		public Float getAverageNumConnections() {
			return averageNumConnections;
		}

		public Float getAveragePassiveOpen() {
			return averagePassiveOpen;
		}
		
		public Float getAverageActiveOpen() {
			return averageActiveOpen;
		}

		public Float getStdevRst() {
			return stdevRst;
		}
		
		public Float getStdevNumConnections() {
			return stdevNumConnections;
		}

		public Float getStdevPassiveOpen() {
			return stdevPassiveOpen;
		}

		public Float getStdevActiveOpen() {
			return stdevActiveOpen;
		}

		public Float getStdevFailedCons() {
			return stdevFailedCons;
		}
		
		public Float getAverageFailedCons() {
			return averageFailedCons;
		}
	
		public void setTimeRecorded(Long timeRecorded) {
			Long temp = this.timeRecorded;
			this.timeRecorded = timeRecorded;
	        pcs.firePropertyChange("timeRecorded", new Long(temp), new Long(timeRecorded));
		}

		public void setRst(Integer rst) {
			Integer temp = this.rst;
			this.rst = rst;
	        pcs.firePropertyChange("rst", new Integer(temp), new Integer(rst));
		}
		
		public void setNumConnections(Integer numConnections) {
			Integer temp = this.numConnections;
			this.numConnections = numConnections;
	        pcs.firePropertyChange("numConnections", new Integer(temp), new Integer(numConnections));
		}
				
		public void setPassiveOpens(Integer passiveOpens) {
			Integer temp = this.passiveOpens;
			this.passiveOpens = passiveOpens;
	        pcs.firePropertyChange("passiveOpens", new Integer(temp), new Integer(passiveOpens));			
		}
		
		public void setActiveOpens(Integer activeOpens) {
			Integer temp = this.activeOpens;
			this.activeOpens = activeOpens;
	        pcs.firePropertyChange("activeOpens", new Integer(temp), new Integer(activeOpens));			
		}
		
		public void setFailedConns(Integer failedConns) {
			Integer temp = this.failedConns;
			this.failedConns = failedConns;
	        pcs.firePropertyChange("failedConns", new Integer(temp), new Integer(failedConns));			
		}
        
		public void setAverageRst(float averageRst) {
			Float temp = this.averageRst;
			this.averageRst = averageRst;
	        pcs.firePropertyChange("averageRst", new Float(temp), new Float(averageRst));			
		}

		public void setAverageNumConnections(float averageNumConnections) {
			Float temp = this.averageNumConnections;
			this.averageNumConnections = averageNumConnections;
	        pcs.firePropertyChange("averageNumConnections", new Float(temp), new Float(averageNumConnections));			
		}

		public void setAveragePassiveOpen(float averagePassiveOpen) {
			Float temp = this.averagePassiveOpen;
			this.averagePassiveOpen = averagePassiveOpen;
	        pcs.firePropertyChange("averagePassiveOpen", new Float(temp), new Float(averagePassiveOpen));			
		}

		public void setAverageActiveOpen(float averageActiveOpen) {
			Float temp = this.averageActiveOpen;
			this.averageActiveOpen = averageActiveOpen;
	        pcs.firePropertyChange("averageActiveOpen", new Float(temp), new Float(averageRst));			
		}

		public void setAverageFailedCons(float averageFailedCons) {
			Float temp = this.averageFailedCons;
			this.averageFailedCons = averageFailedCons;
	        pcs.firePropertyChange("averageFailedCons", new Float(temp), new Float(averageFailedCons));			
		}

		public void setStdevRst(float stdevRst) {
			Float temp = this.stdevRst;
			this.stdevRst = stdevRst;
	        pcs.firePropertyChange("stdevRst", new Float(temp), new Float(stdevRst));			
		}

		public void setStdevNumConnections(float stdevNumConnections) {
			Float temp = this.stdevNumConnections;
			this.stdevNumConnections = stdevNumConnections;
	        pcs.firePropertyChange("stdevNumConnections", new Float(temp), new Float(stdevNumConnections));			
		}

		public void setStdevPassiveOpen(float stdevPassiveOpen) {
			Float temp = this.stdevPassiveOpen;
			this.stdevPassiveOpen = stdevPassiveOpen;
	        pcs.firePropertyChange("stdevPassiveOpen", new Float(temp), new Float(stdevPassiveOpen));			
		}

		public void setStdevActiveOpen(float stdevActiveOpen) {
			Float temp = this.stdevActiveOpen;
			this.stdevActiveOpen = stdevActiveOpen;
	        pcs.firePropertyChange("stdevActiveOpen", new Float(temp), new Float(stdevActiveOpen));			
		}

		public void setStdevFailedCons(float stdevFailedCons) {
			Float temp = this.stdevFailedCons;
			this.stdevFailedCons = stdevFailedCons;
	        pcs.firePropertyChange("stdevFailedCons", new Float(temp), new Float(stdevFailedCons));			
		}


	
        public void updateDynamic() {

        	int size = entryList.size();
        	int startIndex = 0;
        	
    		int sumRst=0;
            int sumNumConnections=0;
            int sumPassiveOpen=0;
            int sumActiveOpen=0;
            int sumFailedCons=0;

        	for (int i=startIndex; i < size; i++) {
        		
        		RSTSystemStats rststat = (RSTSystemStats) entryList.get(i);
        		sumRst += rststat.rst;
        		sumNumConnections += rststat.numConnections;
        		sumPassiveOpen += rststat.passiveOpens;
        		sumActiveOpen += rststat.activeOpens;
        		sumFailedCons += rststat.failedConns;
        	}
        
            float averageRst = ((float) sumRst / (float) size);
            float averageNumConnections = ((float) sumNumConnections / (float) size);
            float averagePassiveOpen = ((float) sumPassiveOpen / (float) size);
            float averageActiveOpen = ((float) sumActiveOpen / (float) size);
            float averageFailedCons = ((float) sumFailedCons / (float) size);
            
            float sdqDevSumRst = 0;
            float sdqDevSumNumConnections = 0;
            float sdqDevSumPassiveOpen = 0;
            float sdqDevSumActiveOpen = 0;
            float sdqDevSumFailedCons = 0;
        	
        	for (int i=startIndex; i < size; i++) {
        		
        		RSTSystemStats rststat = (RSTSystemStats) entryList.get(i);
        		sdqDevSumRst += Math.pow( (averageRst - rststat.rst), 2);
        		sdqDevSumNumConnections += Math.pow( (averageNumConnections - rststat.numConnections), 2);
        		sdqDevSumPassiveOpen += Math.pow( (averagePassiveOpen - rststat.passiveOpens), 2);
        		sdqDevSumActiveOpen += Math.pow( (averageActiveOpen - rststat.activeOpens), 2);
        		sdqDevSumFailedCons += Math.pow( (averageFailedCons - rststat.failedConns), 2);

        	}        	
        	
//            setStdevRst( (float) Math.sqrt(sdqDevSumRst / size ));
//            setStdevNumConnections( (float) Math.sqrt(sdqDevSumNumConnections / size) );
//            setStdevPassiveOpen( (float) Math.sqrt(sdqDevSumPassiveOpen / size) );
//            setStdevActiveOpen( (float) Math.sqrt(sdqDevSumActiveOpen / size) );
//            setStdevFailedCons( (float) Math.sqrt(sdqDevSumFailedCons / size) );
//            
//            setAverageRst((float) sumRst / (float) size);
//            setAverageNumConnections((float) sumNumConnections / (float) size);
//            setAveragePassiveOpen((float) sumPassiveOpen / (float) size);
//            setAverageActiveOpen((float) sumActiveOpen / (float) size);
//            setAverageFailedCons((float) sumFailedCons / (float) size);
        	
            this.stdevRst = ( (float) Math.sqrt(sdqDevSumRst / size ));
            this.stdevNumConnections = ( (float) Math.sqrt(sdqDevSumNumConnections / size) );
            this.stdevPassiveOpen = ( (float) Math.sqrt(sdqDevSumPassiveOpen / size) );
            this.stdevActiveOpen = ( (float) Math.sqrt(sdqDevSumActiveOpen / size) );
            this.stdevFailedCons = ( (float) Math.sqrt(sdqDevSumFailedCons / size) );
            
            this.averageRst = ((float) sumRst / (float) size);
            this.averageNumConnections = ((float) sumNumConnections / (float) size);
            this.averagePassiveOpen = ((float) sumPassiveOpen / (float) size);
            this.averageActiveOpen = ((float) sumActiveOpen / (float) size);
            this.averageFailedCons = ((float) sumFailedCons / (float) size); 

            
        }

        
}
