package edu.northwestern.dasu.drools;

import java.util.HashMap;

import edu.northwestern.dasu.measurement.ProbeType;
import edu.northwestern.dasu.util.Util;

public class FactNdtProbeResult extends FactProbeResult {
	
	public String osName;
	public String osArch;
	public String osVer;
	public String javaVer;
	public String javaVendor;
	public String server;
	public double c2sRate = -1; /*kbps*/
	public double s2cRate = -1; /*kbps*/
	public double mylink;
	public int mismatch;
	public double avgrtt; /*msec*/
	public int packetSize; /*bytes*/
	public int PktsRetrans;
	public int DupAcksIn;
	public int SACKsRcvd;
	public int connectionStalledTimes;
	public double connectionIdlePercentage;
	public boolean c2sPacketQueuing = false;
	public boolean s2cPacketQueuing = false;
	public double s2cThroughputPacketQueueingDetectedPercentage = -1;
	public double connectionReceiverLimitedPercentage = 0;
	public double connectionSenderLimitedPercentage = 0;
	public double connectionNetworkLimitedPercentage = 0;
	public boolean RFC2018; /*Selective Acknowledgement*/
	public boolean RFC896; /*Nagle Algorithm*/
	public boolean RFC3168; /*Explicit Congestion Notification*/
	public boolean RFC1323TimeStamping; /*Time Stamping*/
	public boolean RFC1323WindowScaling; /*Window Scaling*/
	public int serverScalingFactor = 0;
	public int clientScalingFactor = 0;
	public boolean serverBehindFirewall;
	public boolean clientBehindFirewall;
	public double theoreticalNetworkLimit; /*Mbps*/
	public double serverBuffer; /*Kbyte*/
	public double serverThroughputLimit; /*Mbps*/
	public double clientBuffer; /*kbyte*/
	public double clientThroughputLimit; /*Mbps*/
	public long time;
	public boolean failed = false;
	public String errorMsg;
	public HashMap<String, Double> variablesMap;
	
	
	public FactNdtProbeResult() {
		super(ProbeType.NDT);
		variablesMap = new HashMap<String, Double>();
		time = Util.currentGMTTime();
	}


	public String getOsName() {
		return osName;
	}


	public String getOsArch() {
		return osArch;
	}


	public String getOsVer() {
		return osVer;
	}


	public String getJavaVer() {
		return javaVer;
	}


	public String getJavaVendor() {
		return javaVendor;
	}


	public String getServer() {
		return server;
	}


	public double getC2sRate() {
		return c2sRate;
	}


	public double getS2cRate() {
		return s2cRate;
	}


	public double getMylink() {
		return mylink;
	}


	public int getMismatch() {
		return mismatch;
	}


	public double getAvgrtt() {
		return avgrtt;
	}


	public int getPacketSize() {
		return packetSize;
	}


	public int getPktsRetrans() {
		return PktsRetrans;
	}


	public int getDupAcksIn() {
		return DupAcksIn;
	}


	public int getSACKsRcvd() {
		return SACKsRcvd;
	}


	public int getConnectionStalledTimes() {
		return connectionStalledTimes;
	}


	public double getConnectionIdlePercentage() {
		return connectionIdlePercentage;
	}


	public boolean isC2sPacketQueuing() {
		return c2sPacketQueuing;
	}


	public boolean isS2cPacketQueuing() {
		return s2cPacketQueuing;
	}


	public double getS2cThroughputPacketQueueingDetectedPercentage() {
		return s2cThroughputPacketQueueingDetectedPercentage;
	}


	public double getConnectionReceiverLimitedPercentage() {
		return connectionReceiverLimitedPercentage;
	}


	public double getConnectionSenderLimitedPercentage() {
		return connectionSenderLimitedPercentage;
	}


	public double getConnectionNetworkLimitedPercentage() {
		return connectionNetworkLimitedPercentage;
	}


	public boolean isRFC2018() {
		return RFC2018;
	}


	public boolean isRFC896() {
		return RFC896;
	}


	public boolean isRFC3168() {
		return RFC3168;
	}


	public boolean isRFC1323TimeStamping() {
		return RFC1323TimeStamping;
	}


	public boolean isRFC1323WindowScaling() {
		return RFC1323WindowScaling;
	}


	public int getServerScalingFactor() {
		return serverScalingFactor;
	}


	public int getClientScalingFactor() {
		return clientScalingFactor;
	}


	public boolean isServerBehindFirewall() {
		return serverBehindFirewall;
	}


	public boolean isClientBehindFirewall() {
		return clientBehindFirewall;
	}


	public double getTheoreticalNetworkLimit() {
		return theoreticalNetworkLimit;
	}


	public double getServerBuffer() {
		return serverBuffer;
	}


	public double getServerThroughputLimit() {
		return serverThroughputLimit;
	}


	public double getClientBuffer() {
		return clientBuffer;
	}


	public double getClientThroughputLimit() {
		return clientThroughputLimit;
	}


	public long getTime() {
		return time;
	}


	public boolean isFailed() {
		return failed;
	}


	public String getErrorMsg() {
		return errorMsg;
	}


	public HashMap<String, Double> getVariablesMap() {
		return variablesMap;
	}


	public void setOsName(String osName) {
		this.osName = osName;
	}


	public void setOsArch(String osArch) {
		this.osArch = osArch;
	}


	public void setOsVer(String osVer) {
		this.osVer = osVer;
	}


	public void setJavaVer(String javaVer) {
		this.javaVer = javaVer;
	}


	public void setJavaVendor(String javaVendor) {
		this.javaVendor = javaVendor;
	}


	public void setServer(String server) {
		this.server = server;
	}


	public void setC2sRate(double rate) {
		c2sRate = rate;
	}


	public void setS2cRate(double rate) {
		s2cRate = rate;
	}


	public void setMylink(double mylink) {
		this.mylink = mylink;
	}


	public void setMismatch(int mismatch) {
		this.mismatch = mismatch;
	}


	public void setAvgrtt(double avgrtt) {
		this.avgrtt = avgrtt;
	}


	public void setPacketSize(int packetSize) {
		this.packetSize = packetSize;
	}


	public void setPktsRetrans(int pktsRetrans) {
		PktsRetrans = pktsRetrans;
	}


	public void setDupAcksIn(int dupAcksIn) {
		DupAcksIn = dupAcksIn;
	}


	public void setSACKsRcvd(int ksRcvd) {
		SACKsRcvd = ksRcvd;
	}


	public void setConnectionStalledTimes(int connectionStalledTimes) {
		this.connectionStalledTimes = connectionStalledTimes;
	}


	public void setConnectionIdlePercentage(double connectionIdlePercentage) {
		this.connectionIdlePercentage = connectionIdlePercentage;
	}


	public void setC2sPacketQueuing(boolean packetQueuing) {
		c2sPacketQueuing = packetQueuing;
	}


	public void setS2cPacketQueuing(boolean packetQueuing) {
		s2cPacketQueuing = packetQueuing;
	}


	public void setS2cThroughputPacketQueueingDetectedPercentage(
			double throughputPacketQueueingDetectedPercentage) {
		s2cThroughputPacketQueueingDetectedPercentage = throughputPacketQueueingDetectedPercentage;
	}


	public void setConnectionReceiverLimitedPercentage(
			double connectionReceiverLimitedPercentage) {
		this.connectionReceiverLimitedPercentage = connectionReceiverLimitedPercentage;
	}


	public void setConnectionSenderLimitedPercentage(
			double connectionSenderLimitedPercentage) {
		this.connectionSenderLimitedPercentage = connectionSenderLimitedPercentage;
	}


	public void setConnectionNetworkLimitedPercentage(
			double connectionNetworkLimitedPercentage) {
		this.connectionNetworkLimitedPercentage = connectionNetworkLimitedPercentage;
	}


	public void setRFC2018(boolean rfc2018) {
		RFC2018 = rfc2018;
	}


	public void setRFC896(boolean rfc896) {
		RFC896 = rfc896;
	}


	public void setRFC3168(boolean rfc3168) {
		RFC3168 = rfc3168;
	}


	public void setRFC1323TimeStamping(boolean timeStamping) {
		RFC1323TimeStamping = timeStamping;
	}


	public void setRFC1323WindowScaling(boolean windowScaling) {
		RFC1323WindowScaling = windowScaling;
	}


	public void setServerScalingFactor(int serverScalingFactor) {
		this.serverScalingFactor = serverScalingFactor;
	}


	public void setClientScalingFactor(int clientScalingFactor) {
		this.clientScalingFactor = clientScalingFactor;
	}


	public void setServerBehindFirewall(boolean serverBehindFirewall) {
		this.serverBehindFirewall = serverBehindFirewall;
	}


	public void setClientBehindFirewall(boolean clientBehindFirewall) {
		this.clientBehindFirewall = clientBehindFirewall;
	}


	public void setTheoreticalNetworkLimit(double theoreticalNetworkLimit) {
		this.theoreticalNetworkLimit = theoreticalNetworkLimit;
	}


	public void setServerBuffer(double serverBuffer) {
		this.serverBuffer = serverBuffer;
	}


	public void setServerThroughputLimit(double serverThroughputLimit) {
		this.serverThroughputLimit = serverThroughputLimit;
	}


	public void setClientBuffer(double clientBuffer) {
		this.clientBuffer = clientBuffer;
	}


	public void setClientThroughputLimit(double clientThroughputLimit) {
		this.clientThroughputLimit = clientThroughputLimit;
	}


	public void setTime(long time) {
		this.time = time;
	}


	public void setFailed(boolean failed) {
		this.failed = failed;
	}


	public void setErrorMsg(String errorMsg) {
		this.errorMsg = errorMsg;
	}


	public void setVariablesMap(HashMap<String, Double> variablesMap) {
		this.variablesMap = variablesMap;
	}
	
}
