/**
 * News Project
 *
 * File:         DownloadStats.java
 * RCS:          $Id: DownloadStatsSummary.java,v 1.1 2010/05/24 19:21:52 mas939 Exp $
 * Description:  DownloadStats class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 10, 2007 at 1:39:15 PM
 * Language:     Java
 * Package:      edu.northwestern.news.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.stats;


import java.util.ArrayList;
import org.gudy.azureus2.plugins.download.Download;
import org.gudy.azureus2.plugins.download.DownloadListener;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 * 
 * downloadStatSummary, (every 30 minutes), localId, downloadId (for this session), 
 * currentTime (in ms), downloadingTime (time spent downloading), 
 * seedingTime (time spent seeding), maxDownloadRateLimit, maxUploadLimit, 
 * totalUploaded (of bytes for this download), totalDownloaded (of bytes for thisdownload),
 * size (of the download), pieceSize (piece size for download)
 */

public class DownloadStatsSummary{

	public Download download;
	public long downloadingTime;
	public long seedingTime;
	public int maxDownloadRateLimit;
	public int maxUploadLimit;
	public ArrayList<DownloadStatsDynamic> dynamicStats;
	public long totalUploaded;
	public long totalDownloaded;
	public long size;
	public int downloadId;
	public int priority;
	public long pieceSize;
	public DownloadListener dlist;

	public DownloadStatsSummary(Download download) {

		if (download.getState()== Download.ST_DOWNLOADING ||
		     download.getState() == Download.ST_SEEDING){
			
			downloadingTime = download.getStats().getSecondsDownloading();
			seedingTime = download.getStats().getSecondsOnlySeeding();
			maxDownloadRateLimit = download.getMaximumDownloadKBPerSecond();
			maxUploadLimit = download.getUploadRateLimitBytesPerSecond();
			totalUploaded = download.getStats().getUploaded();
			totalDownloaded = download.getStats().getDownloaded();
			size = download.getTorrent().getSize();
			priority = download.getIndex();
			
		}
	}
	
}
