/**
 * News Project
 *
 * File:         DownloadStats.java
 * RCS:          $Id: DynamicLocalPeerStat.java,v 1.1 2010/05/24 19:21:52 mas939 Exp $
 * Description:  DownloadStats class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 10, 2007 at 1:39:15 PM
 * Language:     Java
 * Package:      edu.northwestern.news.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.stats;

import org.gudy.azureus2.core3.config.COConfigurationManager;
import org.gudy.azureus2.core3.config.impl.TransferSpeedValidator;
import org.gudy.azureus2.plugins.download.Download;
import org.gudy.azureus2.plugins.download.DownloadManager;

import edu.northwestern.dasu.MainGeneric;
import edu.northwestern.dasu.util.Util;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 *
 * localPeerStatDynamic, every 30 seconds, peerId, time, uploadRate (at that time), 
 * downloadRate (at that time), maxDonwloadRate, maxUploadRate, autoSeed
 */

public class DynamicLocalPeerStat{
	public long timeRecorded = Util.currentGMTTime();
	public int uploadRate;
	public int downloadRate;
	public int maxUploadRate;
	public int maxDownloadRate;
	public boolean autoSpeed;
	public int rst;
	public int numConnections;
	public int passiveOpens;
	public int activeOpens;
	public int failedConns;
	public int numTorrents = 0;
	public int numLeechingTorrents = 0;
	public int numSeedingTorrents = 0;
	public int numConnectedSeeds = 0;
	public int numConnectedLeechers = 0;
	
	public DynamicLocalPeerStat() {
		
		DownloadManager dm = MainGeneric.getPluginInterface().getDownloadManager();

		downloadRate = dm.getStats().getDataReceiveRate();;
		uploadRate = dm.getStats().getDataSendRate();;
		maxDownloadRate = COConfigurationManager
		.getIntParameter("Max Download Speed KBs");
		maxUploadRate = COConfigurationManager
		.getIntParameter("Max Upload Speed KBs");
		autoSpeed = checkAutoSpeed();
		numTorrents = dm.getDownloads().length;
		
		numConnectedSeeds = 0;
		numConnectedLeechers = 0;
		for (Download d : dm.getDownloads()) {
			if (d.getState() == Download.ST_SEEDING)
				numSeedingTorrents++;
			if (d.getState() == Download.ST_DOWNLOADING)
				numLeechingTorrents++;
			
			if (d.getPeerManager() != null) {
				numConnectedSeeds += d.getPeerManager().getStats().getConnectedSeeds();
				numConnectedLeechers += d.getPeerManager().getStats().getConnectedLeechers();
			}
		}		

	}

	private boolean checkAutoSpeed() {
		String config = "";
		if ( COConfigurationManager.getBooleanParameter(TransferSpeedValidator.AUTO_UPLOAD_ENABLED_CONFIGKEY)){
			
			config = ( TransferSpeedValidator.AUTO_UPLOAD_ENABLED_CONFIGKEY );
		} else {
		
	    	if ( MainGeneric.getPluginInterface().getDownloadManager().isSeedingOnly()){
	        	
	    		config = ( TransferSpeedValidator.AUTO_UPLOAD_SEEDING_ENABLED_CONFIGKEY );
	        	
	      	}else{
	      		
	      		config = ( TransferSpeedValidator.AUTO_UPLOAD_ENABLED_CONFIGKEY );
	      	}
		}
		
		return COConfigurationManager.getBooleanParameter(config);
	}
}